@@ -13,6 +13,7 @@ static const int Cryptography_HAS_X25519;
 static const int Cryptography_HAS_X448;
 static const int Cryptography_HAS_ED448;
 static const int Cryptography_HAS_ED25519;
+static const int Cryptography_HAS_POLY1305;
 
 static const int NID_undef;
 static const int NID_pbe_WithSHA1And3_Key_TripleDES_CBC;
@@ -20,6 +21,7 @@ static const int NID_X25519;
 static const int NID_X448;
 static const int NID_ED25519;
 static const int NID_ED448;
+static const int NID_poly1305;
 
 static const int NID_subject_alt_name;
 static const int NID_crl_reason;
@@ -53,4 +55,10 @@ static const int NID_ED448 = 0;
 #else
 static const long Cryptography_HAS_ED448 = 1;
 #endif
+#ifndef NID_poly1305
+static const long Cryptography_HAS_POLY1305 = 0;
+static const int NID_poly1305 = 0;
+#else
+static const long Cryptography_HAS_POLY1305 = 1;
+#endif
 """
