@@ -168,16 +168,15 @@ def hash_test(backend, algorithm, params):
     assert m.finalize() == binascii.unhexlify(expected_md)
 
 
-def generate_base_hash_test(algorithm, digest_size, block_size):
+def generate_base_hash_test(algorithm, digest_size):
     def test_base_hash(self, backend):
-        base_hash_test(backend, algorithm, digest_size, block_size)
+        base_hash_test(backend, algorithm, digest_size)
     return test_base_hash
 
 
-def base_hash_test(backend, algorithm, digest_size, block_size):
+def base_hash_test(backend, algorithm, digest_size):
     m = hashes.Hash(algorithm, backend=backend)
     assert m.algorithm.digest_size == digest_size
-    assert m.algorithm.block_size == block_size
     m_copy = m.copy()
     assert m != m_copy
     assert m._ctx != m_copy._ctx
@@ -388,13 +387,13 @@ def kbkdf_counter_mode_test(backend, params):
 
     algorithm = supported_algorithms.get(params.get('prf'))
     if algorithm is None or not backend.hmac_supported(algorithm()):
-        pytest.skip("KBKDF does not support algorithm: {0}".format(
+        pytest.skip("KBKDF does not support algorithm: {}".format(
             params.get('prf')
         ))
 
     ctr_loc = supported_counter_locations.get(params.get("ctrlocation"))
     if ctr_loc is None or not isinstance(ctr_loc, CounterLocation):
-        pytest.skip("Does not support counter location: {0}".format(
+        pytest.skip("Does not support counter location: {}".format(
             params.get('ctrlocation')
         ))
 
@@ -434,17 +433,23 @@ def rsa_verification_test(backend, params, hash_alg, pad_factory):
     )
     public_key = public_numbers.public_key(backend)
     pad = pad_factory(params, hash_alg)
-    verifier = public_key.verifier(
-        binascii.unhexlify(params["s"]),
-        pad,
-        hash_alg
-    )
-    verifier.update(binascii.unhexlify(params["msg"]))
+    signature = binascii.unhexlify(params["s"])
+    msg = binascii.unhexlify(params["msg"])
     if params["fail"]:
         with pytest.raises(InvalidSignature):
-            verifier.verify()
+            public_key.verify(
+                signature,
+                msg,
+                pad,
+                hash_alg
+            )
     else:
-        verifier.verify()
+        public_key.verify(
+            signature,
+            msg,
+            pad,
+            hash_alg
+        )
 
 
 def _check_rsa_private_numbers(skey):
